.. audiodiff documentation master file, created by
   sphinx-quickstart on Thu Jan 31 11:29:44 2013.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst


API reference
-------------

.. automodule:: audiodiff
   :members:


Indices and tables
------------------

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
